==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfLayoutWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLayoutWidget(PdfGraphicsWidget):
    """
    Represents the base class for all elements that can be layout on the pages.
    """
    @dispatch
    def Draw(self, page, location: PointF) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            location: Start location on the page.

        Returns:
            Layouting result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlocation: c_void_p = location.Ptr

        GetDllLibPdf().PdfLayoutWidget_Draw.argtypes = [c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_Draw.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutWidget_Draw(self.Ptr, intPtrpage, intPtrlocation)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, x: float, y: float) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            x: X co-ordinate of the element on the page.
            y: Y co-ordinate of the element on the page.

        Returns:
            Lay outing result.
        """
        intPtrpage:c_void_p = page.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPXY.argtypes=[c_void_p ,c_void_p,c_float,c_float]
        GetDllLibPdf().PdfLayoutWidget_DrawPXY.restype=c_void_p
        intPtr = GetDllLibPdf().PdfLayoutWidget_DrawPXY(self.Ptr, intPtrpage,x,y)
        ret = None if intPtr==None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, layoutRectangle: RectangleF) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            layoutRectangle: RectangleF structure that specifies the bounds of the element.

        Returns:
            Lay outing result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlayoutRectangle: c_void_p = layoutRectangle.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPL.argtypes = [c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_DrawPL.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutWidget_DrawPL(self.Ptr, intPtrpage, intPtrlayoutRectangle)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, layoutRectangle: RectangleF, embedFonts: bool) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            layoutRectangle: RectangleF structure that specifies the bounds of the element.
            embedFonts: Whether to embed fonts.

        Returns:
            Lay outing result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlayoutRectangle: c_void_p = layoutRectangle.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPLE.argtypes = [c_void_p, c_void_p, c_void_p, c_bool]
        GetDllLibPdf().PdfLayoutWidget_DrawPLE.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutWidget_DrawPLE(self.Ptr, intPtrpage, intPtrlayoutRectangle, embedFonts)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, location: PointF, format: PdfTextLayout) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            location: Start location on the page.
            format: Lay outing format.

        Returns:
            Lay outing result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlocation: c_void_p = location.Ptr
        intPtrformat: c_void_p = format.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPLF.argtypes = [c_void_p, c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_DrawPLF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutWidget_DrawPLF(self.Ptr, intPtrpage, intPtrlocation, intPtrformat)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, x: float, y: float, format: PdfTextLayout) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            x: X co-ordinate of the element on the page.
            y: Y co-ordinate of the element on the page.
            format: Layout format.

        Returns:
            Layout result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrformat: c_void_p = format.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPXYF.argtypes = [c_void_p, c_void_p, c_float, c_float, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_DrawPXYF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutWidget_DrawPXYF(self.Ptr, intPtrpage, x, y, intPtrformat)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, layoutRectangle: RectangleF, format: PdfTextLayout) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            layoutRectangle: RectangleF structure that specifies the bounds of the element.
            format: Layout format.

        Returns:
            Layout result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlayoutRectangle: c_void_p = layoutRectangle.Ptr
        intPtrformat: c_void_p = format.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPLF1.argtypes = [c_void_p, c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_DrawPLF1.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutWidget_DrawPLF1(self.Ptr, intPtrpage, intPtrlayoutRectangle, intPtrformat)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfLayoutWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLayoutWidget(PdfGraphicsWidget):
    """
    Represents the base class for all elements that can be layout on the pages.
    """
    @dispatch
    def Draw(self, page, location: PointF) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            location: Start location on the page.

        Returns:
            Layouting result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlocation: c_void_p = location.Ptr

        GetDllLibPdf().PdfLayoutWidget_Draw.argtypes = [c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_Draw.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutWidget_Draw,self.Ptr, intPtrpage, intPtrlocation)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, x: float, y: float) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            x: X co-ordinate of the element on the page.
            y: Y co-ordinate of the element on the page.

        Returns:
            Lay outing result.
        """
        intPtrpage:c_void_p = page.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPXY.argtypes=[c_void_p ,c_void_p,c_float,c_float]
        GetDllLibPdf().PdfLayoutWidget_DrawPXY.restype=c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutWidget_DrawPXY,self.Ptr, intPtrpage,x,y)
        ret = None if intPtr==None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, layoutRectangle: RectangleF) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            layoutRectangle: RectangleF structure that specifies the bounds of the element.

        Returns:
            Lay outing result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlayoutRectangle: c_void_p = layoutRectangle.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPL.argtypes = [c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_DrawPL.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutWidget_DrawPL,self.Ptr, intPtrpage, intPtrlayoutRectangle)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, layoutRectangle: RectangleF, embedFonts: bool) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            layoutRectangle: RectangleF structure that specifies the bounds of the element.
            embedFonts: Whether to embed fonts.

        Returns:
            Lay outing result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlayoutRectangle: c_void_p = layoutRectangle.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPLE.argtypes = [c_void_p, c_void_p, c_void_p, c_bool]
        GetDllLibPdf().PdfLayoutWidget_DrawPLE.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutWidget_DrawPLE,self.Ptr, intPtrpage, intPtrlayoutRectangle, embedFonts)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, location: PointF, format: PdfTextLayout) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            location: Start location on the page.
            format: Lay outing format.

        Returns:
            Lay outing result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlocation: c_void_p = location.Ptr
        intPtrformat: c_void_p = format.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPLF.argtypes = [c_void_p, c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_DrawPLF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutWidget_DrawPLF,self.Ptr, intPtrpage, intPtrlocation, intPtrformat)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, x: float, y: float, format: PdfTextLayout) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            x: X co-ordinate of the element on the page.
            y: Y co-ordinate of the element on the page.
            format: Layout format.

        Returns:
            Layout result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrformat: c_void_p = format.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPXYF.argtypes = [c_void_p, c_void_p, c_float, c_float, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_DrawPXYF.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutWidget_DrawPXYF,self.Ptr, intPtrpage, x, y, intPtrformat)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret

    @dispatch
    def Draw(self, page, layoutRectangle: RectangleF, format: PdfTextLayout) -> PdfLayoutResult:
        """
        Draws the element on the page.

        Args:
            page: Current page where the element should be drawn.
            layoutRectangle: RectangleF structure that specifies the bounds of the element.
            format: Layout format.

        Returns:
            Layout result.
        """
        intPtrpage: c_void_p = page.Ptr
        intPtrlayoutRectangle: c_void_p = layoutRectangle.Ptr
        intPtrformat: c_void_p = format.Ptr

        GetDllLibPdf().PdfLayoutWidget_DrawPLF1.argtypes = [c_void_p, c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutWidget_DrawPLF1.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayoutWidget_DrawPLF1,self.Ptr, intPtrpage, intPtrlayoutRectangle, intPtrformat)
        ret = None if intPtr == None else PdfLayoutResult(intPtr)
        return ret
